@@ -4,11 +4,11 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/acp.el
-;; Package-Version: 0.11.1
-;; Package-Revision: 784b00017262
+;; Package-Version: 20251116.1155
+;; Package-Revision: 3c6a39c09684
 ;; Package-Requires: ((emacs "28.1"))
 
-(defconst acp-package-version "0.11.1")
+(defconst acp-package-version "0.7.2")
 
 ;; This package is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@
 
 (cl-defun acp-make-client (&key context-buffer command command-params environment-variables
                                 request-sender notification-sender request-resolver
-                                response-sender outgoing-request-decorator)
+                                response-sender)
   "Create an ACP client.
 
 This returns a alist representing the client.
@@ -69,13 +69,7 @@ COMMAND-PARAMS is a list of strings for command arguments.
 ENVIRONMENT-VARIABLES is a list of strings in the form \"VAR=foo\".
 
 REQUEST-SENDER, NOTIFICATION-SENDER, REQUEST-RESOLVER, and RESPONSE-SENDER are
-functions for advanced customization or testing.
-
-OUTGOING-REQUEST-DECORATOR is an optional function of the form
-\(lambda (request) ...) that receives the JSON-RPC request object
-before it is sent and returns a (possibly modified) request.
-If the decorator returns nil, the original request is sent and
-the error is logged."
+functions for advanced customization or testing."
   (unless command
     (error ":command is required"))
   (list (cons :context-buffer context-buffer)
@@ -92,8 +86,7 @@ the error is logged."
         (cons :request-sender (or request-sender #'acp--request-sender))
         (cons :notification-sender (or notification-sender #'acp--notification-sender))
         (cons :request-resolver (or request-resolver #'acp--request-resolver))
-        (cons :response-sender (or response-sender #'acp--response-sender))
-        (cons :outgoing-request-decorator outgoing-request-decorator)))
+        (cons :response-sender (or response-sender #'acp--response-sender))))
 
 (defun acp--client-started-p (client)
   "Return non-nil if CLIENT process has been started."
@@ -125,16 +118,10 @@ the error is logged."
                        :buffer stderr-buffer
                        :filter (lambda (_process raw-output)
                                  (acp--log client "STDERR" "%s" (string-trim raw-output))
-                                 (when-let ((std-error (cond
-                                                        ((acp--parse-stderr-api-error raw-output)
-                                                         (acp--parse-stderr-api-error raw-output))
-                                                        ((not (string-empty-p (string-trim raw-output)))
-                                                         ;; Fallback: create a generic error response
-                                                         `((code . -32603)
-                                                           (message . ,raw-output))))))
+                                 (when-let ((api-error (acp--parse-stderr-api-error raw-output)))
                                    (acp--log client "API-ERROR" "%s" (string-trim raw-output))
                                    (dolist (handler (map-elt client :error-handlers))
-                                     (funcall handler std-error)))))))
+                                     (funcall handler api-error)))))))
     (let ((process (make-process
                     :name (format "acp-client(%s)-%s"
                                   (map-elt client :command)
@@ -267,16 +254,15 @@ Note: These are agent process errors.
   "Shutdown ACP CLIENT and release resources."
   (unless client
     (error ":client is required"))
-  (if (and (or (not (map-elt client :process))
-               (process-live-p (map-elt client :process)))
-           (buffer-live-p (acp-logs-buffer :client client))
-           (buffer-live-p (acp-traffic-buffer :client client)))
-      (progn
-        (when (process-live-p (map-elt client :process))
-          (delete-process (map-elt client :process)))
-        (kill-buffer (acp-logs-buffer :client client))
-        (kill-buffer (acp-traffic-buffer :client client)))
-    (message "Client already shut down")))
+  (unless (and (or (not (map-elt client :process))
+                   (process-live-p (map-elt client :process)))
+               (buffer-live-p (acp-logs-buffer :client client))
+               (buffer-live-p (acp-traffic-buffer :client client)))
+    (error "Client already shut down"))
+  (when (process-live-p (map-elt client :process))
+    (delete-process (map-elt client :process)))
+  (kill-buffer (acp-logs-buffer :client client))
+  (kill-buffer (acp-traffic-buffer :client client)))
 
 (cl-defun acp-send-request (&key client request buffer on-success on-failure sync)
   "Send REQUEST from CLIENT.
@@ -328,12 +314,6 @@ SYNC: When non-nil, send request synchronously."
     (error ":request is required"))
   (unless (acp--client-started-p client)
     (acp--start-client :client client))
-  (when-let ((decorator (map-elt client :outgoing-request-decorator)))
-    (if-let ((decorated (funcall decorator request)))
-        (setq request decorated)
-      (acp--log client "DECORATOR ERROR"
-                "Outgoing request decorator returned nil for \"%s\", sending original request"
-                (map-elt request :method))))
   (let* ((method (map-elt request :method))
          (params (map-elt request :params))
          (proc (map-elt client :process))
@@ -389,18 +369,13 @@ SYNC: When non-nil, send request synchronously."
   (unless response
     (error ":response is required"))
   (let* ((request-id (map-elt response :request-id))
-         (result-data (map-elt response :result))
-         (error-data (map-elt response :error)))
+         (result-data (map-elt response :result)))
     (map-put! client :request-id (or request-id
                                      (1+ (map-elt client :request-id))))
     (let* ((proc (map-elt client :process))
-           (response (if error-data
-                         `((jsonrpc . ,acp--jsonrpc-version)
-                           (id . ,request-id)
-                           (error . ,error-data))
-                       `((jsonrpc . ,acp--jsonrpc-version)
-                         (id . ,request-id)
-                         (result . ,result-data)))))
+           (response `((jsonrpc . ,acp--jsonrpc-version)
+                       (id . ,request-id)
+                       (result . ,result-data))))
       (let ((json (acp--serialize-json response)))
         (acp--log-traffic client 'outgoing 'response (acp--make-message :object response :json json))
         (process-send-string proc json)))))
@@ -439,14 +414,11 @@ When non-nil SYNC, send notification synchronously."
         result))))
 
 (cl-defun acp-make-initialize-request (&key protocol-version
-                                            client-info
                                             read-text-file-capability
                                             write-text-file-capability)
   "Instantiate an \"initialize\" request.
 
 PROTOCOL-VERSION is the version of the ACP protocol to use.
-CLIENT-INFO is an optional alist with client information containing
-keys like `name', `title', and `version'.
 READ-TEXT-FILE-CAPABILITY is a boolean indicating if the client
 can read text files.
 WRITE-TEXT-FILE-CAPABILITY is a boolean indicating if the client
@@ -457,9 +429,7 @@ and https://agentclientprotocol.com/protocol/schema#initializeresponse."
   (unless protocol-version
     (error ":protocol-version is required"))
   `((:method . "initialize")
-    (:params . (,@(when client-info
-                    `((clientInfo . ,client-info)))
-                (protocolVersion . ,protocol-version)
+    (:params . ((protocolVersion . ,protocol-version)
                 (clientCapabilities . ((fs . ((readTextFile . ,(if read-text-file-capability
                                                                    t
                                                                  :false))
@@ -467,39 +437,30 @@ and https://agentclientprotocol.com/protocol/schema#initializeresponse."
                                                                     t
                                                                   :false))))))))))
 
-(cl-defun acp-make-authenticate-request (&key method-id method)
+(cl-defun acp-make-authenticate-request (&key method-id)
   "Instantiate an \"authenticate\" request.
 
-METHOD-ID and METHOD (optionally) for authentication method to use.
+METHOD-ID is the authentication method to use.
 
 See https://agentclientprotocol.com/protocol/schema#authenticaterequest."
   (unless method-id
     (error ":method-id is required"))
   `((:method . "authenticate")
-    (:params . ,(append `((methodId . ,method-id))
-                        (when method
-                          `((authMethod . ,method)))))))
+    (:params . ((methodId . ,method-id)))))
 
-(cl-defun acp-make-session-new-request (&key cwd mcp-servers meta)
+(cl-defun acp-make-session-new-request (&key cwd mcp-servers)
   "Instantiate a \"session/new\" request.
 
 CWD is the current working directory for the session.
 MCP-SERVERS is a list of MCP servers to use.
-META is an optional alist of metadata to pass to the agent.
-  Supported keys include:
-  - `systemPrompt': Either a string (replaces default) or
-    an alist with key `append' containing a string to append
-    to the default system prompt.
 
 See https://agentclientprotocol.com/protocol/schema#newsessionrequest
 and https://agentclientprotocol.com/protocol/schema#newsessionresponse."
   (unless cwd
     (error ":cwd is required"))
   `((:method . "session/new")
-    ;; directory-file-name removes any trailing /
-    (:params . ((cwd . ,(directory-file-name (expand-file-name cwd)))
-                (mcpServers . ,(or mcp-servers []))
-                ,@(when meta `((_meta . ,meta)))))))
+    (:params . ((cwd . ,(expand-file-name cwd))
+                (mcpServers . ,(or mcp-servers []))))))
 
 (cl-defun acp-make-session-prompt-request (&key session-id prompt)
   "Instantiate a \"session/prompt\" request.
@@ -533,92 +494,6 @@ See https://agentclientprotocol.com/protocol/session-modes"
     (:params . ((sessionId . ,session-id)
                 (modeId . ,mode-id)))))
 
-(cl-defun acp-make-session-set-model-request (&key session-id model-id)
-  "Instantiate a \"session/set_model\" request.
-
-SESSION-ID is the ID of the session to change the model for.
-MODEL-ID is the model to set (e.g., \"default\", \"haiku\").
-
-This is a claude-code-acp extension to the ACP protocol.
-
-See https://docs.claude.com/en/api/agent-sdk/typescript"
-  (unless session-id
-    (error ":session-id is required"))
-  (unless model-id
-    (error ":model-id is required"))
-  `((:method . "session/set_model")
-    (:params . ((sessionId . ,session-id)
-                (modelId . ,model-id)))))
-
-(cl-defun acp-make-session-resume-request (&key session-id cwd mcp-servers)
-  "Instantiate a \"session/resume\" request.
-
-SESSION-ID is the ID of the session to resume.
-CWD is the current working directory for the resumed session.
-MCP-SERVERS is an optional list of MCP servers to use.
-
-This method resumes an existing session without returning previous messages
-\(unlike `session/load').  Only available if the agent advertises the
-`session.resume' capability.
-
-Note: This is an unstable ACP feature.
-
-See https://agentclientprotocol.com/rfds/session-resume."
-  (unless session-id
-    (error ":session-id is required"))
-  (unless cwd
-    (error ":cwd is required"))
-  `((:method . "session/resume")
-    (:params . ((sessionId . ,session-id)
-                ;; directory-file-name removes any trailing /
-                (cwd . ,(directory-file-name (expand-file-name cwd)))
-                (mcpServers . ,(or mcp-servers []))))))
-
-(cl-defun acp-make-session-list-request (&key cwd)
-  "Instantiate a \"session/list\" request.
-
-CWD is the current working directory used to filter sessions.
-
-Note: This is an unstable ACP feature.
-
-See https://agentclientprotocol.com/rfds/session-list."
-  (unless cwd
-    (error ":cwd is required"))
-  `((:method . "session/list")
-    ;; directory-file-name removes any trailing /
-    (:params . ((cwd . ,(directory-file-name (expand-file-name cwd)))))))
-
-(cl-defun acp-make-session-load-request (&key session-id cwd mcp-servers)
-  "Instantiate a \"session/load\" request.
-
-SESSION-ID is the ID of the session to load.
-CWD is the current working directory for the loaded session.
-MCP-SERVERS is an optional list of MCP servers to use.
-
-See https://agentclientprotocol.com/protocol/schema#session-load."
-  (unless session-id
-    (error ":session-id is required"))
-  (unless cwd
-    (error ":cwd is required"))
-  `((:method . "session/load")
-    (:params . ((sessionId . ,session-id)
-                ;; directory-file-name removes any trailing /
-                (cwd . ,(directory-file-name (expand-file-name cwd)))
-                (mcpServers . ,(or mcp-servers []))))))
-
-(cl-defun acp-make-session-delete-request (&key session-id)
-  "Instantiate a \"session/delete\" request.
-
-SESSION-ID is the ID of the session to delete.
-
-Note: This is an unstable ACP feature.
-
-See https://agentclientprotocol.com/rfds/session-delete."
-  (unless session-id
-    (error ":session-id is required"))
-  `((:method . "session/delete")
-    (:params . ((sessionId . ,session-id)))))
-
 (cl-defun acp-make-session-request-permission-response (&key request-id option-id cancelled)
   "Instantiate a \"session/request_permission\" response.
 
